@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>                      */
 
 #include "filterkmail_maildir.h"
 
@@ -27,13 +27,11 @@ class MailImporter::FilterKMail_maildirPrivate
 {
 public:
     FilterKMail_maildirPrivate()
-        : mImportDirDone(0)
-        , mTotalDir(0)
     {
     }
 
-    int mImportDirDone;
-    int mTotalDir;
+    int mImportDirDone = 0;
+    int mTotalDir = 0;
 };
 
 /** Default constructor. */
@@ -170,7 +168,7 @@ void FilterKMail_maildir::importFiles(const QString &dirName)
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
                     if (!(_cat == *mailFile)) {
-                        if (_cat.startsWith(QLatin1Char('.')) && _cat.endsWith(QStringLiteral(".directory"))) {
+                        if (_cat.startsWith(QLatin1Char('.')) && _cat.endsWith(QLatin1String(".directory"))) {
                             _cat.remove(0, 1);
                             _cat.remove((_cat.length() - 10), 10);
                         } else if (_cat.startsWith(QLatin1Char('.'))) {
@@ -179,7 +177,7 @@ void FilterKMail_maildir::importFiles(const QString &dirName)
                         _path += QLatin1Char('/') + _cat;
                     }
                 }
-                if (_path.endsWith(QStringLiteral("cur"))) {
+                if (_path.endsWith(QLatin1String("cur"))) {
                     _path.remove(_path.length() - 4, 4);
                 }
                 QString _info = _path;
